package com.inspect.metadata.alg.mapper;

import com.inspect.metadata.alg.domain.BasedataAlgSubtype;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface BasedataAlgSubtypeMapper {
    BasedataAlgSubtype selectBasedataAlgSubtypeByAlgSubtypeId(Long subtypeId);

    List<BasedataAlgSubtype> selectBasedataAlgSubtypeList(BasedataAlgSubtype var1);

    int insertBasedataAlgSubtype(BasedataAlgSubtype subtype);

    int updateBasedataAlgSubtype(BasedataAlgSubtype subtype);

    int deleteBasedataAlgSubtypeByAlgSubtypeId(Long subtypeId);

    int deleteBasedataAlgSubtypeByAlgSubtypeIds(Long[] subtypeIds);

    int checkAlgSubtypeNameIsExit(@Param("algSubtypeId") String algSubtypeId, @Param("algId") String algId, @Param("algSubtypeName") String algSubtypeName);
}
